DialogHandler

Trait DialogHandler 

pub trait DialogHandler: Sized {
    // Required methods
    fn request_close(
        &mut self,
        conn: &Connection,
        qh: &QueueHandle<Self>,
        window: &Dialog,
    );
    fn configure(
        &mut self,
        conn: &Connection,
        qh: &QueueHandle<Self>,
        window: &Dialog,
        configure: WindowConfigure,
        serial: u32,
    );
}
Handler for toplevel operations on a Dialog

Required Methods

fn request_close( &mut self, conn: &Connection, qh: &QueueHandle<Self>, window: &Dialog, )

Request to close a dialog.

This request does not destroy the dialog. You must drop all Dialog handles to destroy the dialog. This request may be sent either by the compositor or by some other mechanism (such as client side decorations).

fn configure( &mut self, conn: &Connection, qh: &QueueHandle<Self>, window: &Dialog, configure: WindowConfigure, serial: u32, )

Apply a suggested surface change.

When this function is called, the compositor is requesting the window’s size or state to change.

Internally this function is called when the underlying xdg_surface is configured. Any extension protocols that interface with xdg-shell are able to be notified that the surface’s configure sequence is complete by using this function.

Double buffering

Configure events in Wayland are considered to be double buffered and the state of the window does not change until committed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors